package com.ruoyi.web.controller.info;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.UserInfo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.UserNucleicTime;
import com.ruoyi.system.service.IUserNucleicTimeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 导入人员核酸时间记录Controller
 * 
 * @author ruoyi
 * @date 2022-08-15
 */
@RestController
@RequestMapping("/system/time")
public class UserNucleicTimeController extends BaseController
{
    @Autowired
    private IUserNucleicTimeService userNucleicTimeService;

    /**
     * 查询导入人员核酸时间记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(UserNucleicTime userNucleicTime)
    {
        startPage();
        List<UserNucleicTime> list = userNucleicTimeService.selectUserNucleicTimeList(userNucleicTime);
        return getDataTable(list);
    }


    /**
     * 查询首页本周核酸人员列表
     */
    @GetMapping("/homeList")
    public TableDataInfo homeList()
    {
        startPage();
        List<UserNucleicTime> list = userNucleicTimeService.homeList();
        return getDataTable(list);
    }

    /**
     * 导出导入人员核酸时间记录列表
     */
    @Log(title = "导入人员核酸时间记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserNucleicTime userNucleicTime)
    {
        List<UserNucleicTime> list = userNucleicTimeService.selectUserNucleicTimeList(userNucleicTime);
        ExcelUtil<UserNucleicTime> util = new ExcelUtil<UserNucleicTime>(UserNucleicTime.class);
        util.exportExcel(response, list, "导入人员核酸时间记录数据");
    }

    /**
     * 获取导入人员核酸时间记录详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(userNucleicTimeService.selectUserNucleicTimeById(id));
    }

    /**
     * 新增导入人员核酸时间记录
     */
    @Log(title = "导入人员核酸时间记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UserNucleicTime userNucleicTime)
    {
        return toAjax(userNucleicTimeService.insertUserNucleicTime(userNucleicTime));
    }

    /**
     * 修改导入人员核酸时间记录
     */
    @Log(title = "导入人员核酸时间记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UserNucleicTime userNucleicTime)
    {
        return toAjax(userNucleicTimeService.updateUserNucleicTime(userNucleicTime));
    }

    /**
     * 删除导入人员核酸时间记录
     */
    @Log(title = "导入人员核酸时间记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(userNucleicTimeService.deleteUserNucleicTimeByIds(ids));
    }
}
